<?php
/*
Plugin Name: Fraktjakt Shipping Method for WooCommerce
Plugin URI: http://www.fraktjakt.se
Description: Fraktjakt shipping method plugin for WooCommerce. Integrates Bussgods, DHL, DSV, FedEx, Posten/PostNOrd, Schenker, UPS and more through Fraktjakt.
Version: 1.2.1
Author: Fraktjakt
Author URI: http://www.fraktjakt.se
*/

/**
 * Check if WooCommerce is active
 */
if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {

	function fraktjakt_shipping_method_init() {
		if ( ! class_exists( 'WC_Fraktjakt_Shipping_Method' ) ) {
			class WC_Fraktjakt_Shipping_Method extends WC_Shipping_Method {
				
				//$consignor_key;
				
				/**
				 * Constructor for your shipping class
				 *
				 * @access public
				 * @return void
				 */
				public function __construct() {
					$this->id                 = 'fraktjakt_shipping_method'; // Id for your shipping method. Should be uunique.
					$this->method_title       = __( 'Fraktjakt Shipping Method','fraktjakt-woocommerce-shipping' );  // Title shown in admin
					//$this->consignor_key = '000000000';
					$this->init();
				}

				/**
				 * Init your settings
				 *
				 * @access public
				 * @return void
				 */
				function init() {
					// Load the settings API
					$this->init_form_fields(); // This is part of the settings API. Override the method to add your own settings
					$this->init_settings(); // This is part of the settings API. Loads settings you previously init.
					
					$this->enabled	= isset( $this->settings['enabled'] ) ? $this->settings['enabled'] : 'no';
					$this->title	= isset( $this->settings['title'] ) ? $this->settings['title'] : 'Fraktjakt';
					$this->consignor_id		= isset( $this->settings['consignor_id'] ) ? $this->settings['consignor_id'] : '';
					$this->consignor_key	= isset( $this->settings['consignor_key'] ) ? $this->settings['consignor_key'] : '';
					$this->fee		= isset( $this->settings['fee'] ) ? $this->settings['fee'] : '';
					$this->test_mode			= isset( $this->settings['test_mode'] ) ? $this->settings['test_mode'] : 0;
					$this->shipping_company_info	= isset( $this->settings['shipping_company_info'] ) ? $this->settings['shipping_company_info'] : 'no';
					$this->shipping_product_info	= isset( $this->settings['shipping_product_info'] ) ? $this->settings['shipping_product_info'] : 'no';
					$this->distance_closest_delivery_info	= isset( $this->settings['distance_closest_delivery_info'] ) ? $this->settings['distance_closest_delivery_info'] : 'no';
					$this->estimated_delivery_info	= isset( $this->settings['estimated_delivery_info'] ) ? $this->settings['estimated_delivery_info'] : 'no';
					
					$this->fallback_service_name	= isset( $this->settings['fallback_service_name'] ) ? $this->settings['fallback_service_name'] : 'Fraktjakt';
					$this->fallback_service_price	= isset( $this->settings['fallback_service_price'] ) ? $this->settings['fallback_service_price'] :25.0;
					$this->dropoff_title	= isset( $this->settings['dropoff_title'] ) ? $this->settings['dropoff_title'] :"Home delivery";
				
					$this->fraktjakt_admin_email	= isset( $this->settings['fraktjakt_admin_email'] ) ? $this->settings['fraktjakt_admin_email'] :"";
				
					$this->uri_query=($this->test_mode=='yes')?'http://api2.fraktjakt.se/':'http://api1.fraktjakt.se/';
					
					$args = array(
						'post_type' => 'product',
						'posts_per_page' => '-1'
					);
					$product_query = new WP_Query( $args );
					$product_errors = 0;
					
					 if($product_query->have_posts()) {
					 	$post_count = $product_query->post_count;
				        $posts = $product_query->posts;
				        $problem_products = array();
				        
				        for ($i = 0; $i < $post_count; $i++) {
				        	$product = new WC_Product( $posts[$i]->ID );
				        	
					        if($product->weight == ''
						            || $product->length == ''
						            || $product->width == ''
						            || $product->height == ''
						            || $product->weight <= 0
						            || $product->length <= 0
						            || $product->width <= 0
						            || $product->height <= 0)
						        {
								    array_push($problem_products, $posts[$i]);
								    $product_errors++;
					            }
					            
				        }
				        
				        // Save settings in admin if you have any defined
						add_action( 'woocommerce_update_options_shipping_' . $this->id, array( $this, 'process_admin_options' ), 1 );
				        
				        add_action('admin_notices', function() use ($product_errors, $problem_products) {
				        	if ($product_errors > 0) {
				        		$class = "error";
						        $message = "Fraktjakt Warning: ".$product_errors." products are missing (or have invalid) weight or dimensions!";
								echo"<div class=\"$class\"> <p>";
								echo $message;
								echo "<br><span style=\"font-size: 10px; line-height: 1;\">";
						        $links = "";
								foreach($problem_products as $post) {
									$links += edit_post_link($post->post_name, '', ', ', $post->ID);
								}
	        					echo"</span></p></div>";
				        	}
					        
					    }, 2);
				        
				    }
					
					$consignor_id = wp_kses_post( trim( stripslashes( $this->plugin_id . $this->id . '_' . $key ) ) );
					$consignor_key = wp_kses_post( trim( stripslashes( $this->plugin_id . $this->id . '_' . 'consignor_key' ) ) );
					$testMode = wp_kses_post( trim( stripslashes( $_POST[ $this->plugin_id . $this->id . '_' . 'test_mode' ] ) ) );
					
					$uri_query=($testMode=='yes')?'http://api2.fraktjakt.se/':'http://api1.fraktjakt.se/';
					
					/*add_action('all_admin_notices', function() use($consignor_id, $consignor_key, $uri_query, $testMode) {
						$class = "error";
						echo"<div class=\"$class\"><p>Fraktjakt Warning:</p> <p>$consignor_key</p></div>";
						/*if (($errmsg = test_connection($this->consignor_id, $this->consignor_key, $this->uri_query)) != "") {
							$class = "error";
						    echo"<div class=\"$class\"><p>Fraktjakt Warning:</p> <p>$errmsg</p></div>";
						}*/
					//}, 10);

					/*<if ($this->consignor_id == '' || $this->consignor_key == '') {
						//add_action( 'all_admin_notices', 'consignor_admin_error_notice' ); 
					}*/
					
					
				}


				
	function init_form_fields() {
				global $woocommerce;

		$this->form_fields = array(
		    'enabled' => array(
				'title' => __('Enable Fraktjakt', 'fraktjakt-woocommerce-shipping'),
				'type' => 'checkbox',
				'label' => __('Enable Fraktjakt', 'fraktjakt-woocommerce-shipping'),
				'default' => ''
		    ),
			 'test_mode' => array(
				'title' => __('Enable Test Mode', 'fraktjakt-woocommerce-shipping'),
				'type' => 'checkbox',
				'description' => __('Test this shipping integration using Fraktjakts TEST servers before entering our production environment. <br />(Note: Requires a separate account in <a href=http://api2.fraktjakt.se/account/register target=_blank>Fraktjakt TEST server</a> as well)'),
				'label' => __('Enable Test Mode', 'fraktjakt-woocommerce-shipping'),
				'default' => ''
		    ),
		    'title' => array(
				'title' => __('Fraktjakt titles', 'fraktjakt-woocommerce-shipping'),
				'type' => 'text',
				'description' => __('Enter the title of the shipping method.', 'fraktjakt-woocommerce-shipping'),
				'default' => __('Fraktjakt title', 'fraktjakt-woocommerce-shipping')
		    ),
		    'consignor_id'           => array(
				'title'           => __( 'Consignor ID', 'fraktjakt-woocommerce-shipping' ),
				'type'            => 'text',
				'description'     => __( 'Your Fraktjakt Consignor Id', 'fraktjakt-woocommerce-shipping' ),
		    ),
		    'consignor_key' => array(
				'title' => __('Consignor Key', 'fraktjakt-woocommerce-shipping'),
				'type' => 'text',
				'description' => __('Your Fraktjakt Consignor Key', 'fraktjakt-woocommerce-shipping'),
			),
			  'fee' => array(
				'title' => __('Handling Fee', 'fraktjakt-woocommerce-shipping'),
				'type' => 'text',
				'description' => __('Additional fee excluding tax. Enter an amount, e.g. 2.50, or a percentage, e.g. 5%. Leave blank for no fee.', 'fraktjakt-woocommerce-shipping')
		    
		  ),
			  'shipping_company_info' => array(
				'title' => __('Shipping company title', 'fraktjakt-woocommerce-shipping'),
				'type' => 'checkbox',
				'description' => __('Display the Shipping company title (on/off)', 'fraktjakt-woocommerce-shipping')
		    )
			,
			  'shipping_product_info' => array(
				'title' => __('Shipping product title', 'fraktjakt-woocommerce-shipping'),
				'type' => 'checkbox',
				'description' => __('Display the Shipping product title (on/off)', 'fraktjakt-woocommerce-shipping')
		    )
			,
			  'distance_closest_delivery_info' => array(
				'title' => __('Distance to closest agent/home delivery info', 'fraktjakt-woocommerce-shipping'),
				'type' => 'checkbox',
				'description' => __('Display the Distance to closest agent/home delivery (on/off)', 'fraktjakt-woocommerce-shipping')
		    ),
		  'estimated_delivery_info' => array(
				'title' => __('Estimated delivery time info', 'fraktjakt-woocommerce-shipping'),
				'type' => 'checkbox',
				'description' => __('Display the Estimated delivery time (on/off)', 'fraktjakt-woocommerce-shipping')
		    )
			 ,
			 'fallback_service_name' => array(
				'title' => __('Fallback service name', 'fraktjakt-woocommerce-shipping'),
				'type' => 'text',
				'description' => __('Fallback service name', 'fraktjakt-woocommerce-shipping')
		    )
			 ,
			 'fallback_service_price' => array(
				'title' => __('Fallback service price', 'fraktjakt-woocommerce-shipping'),
				'type' => 'text',
				'description' => __('Fallback service price', 'fraktjakt-woocommerce-shipping')
		    ),
			 'dropoff_title' => array(
				'title' => __('Dropoff title', 'fraktjakt-woocommerce-shipping'),
				'type' => 'text',
				'description' => __('Shipping services with dropoff included will have this title displayed', 'fraktjakt-woocommerce-shipping')
		    )
			,
			 'fraktjakt_admin_email' => array(
				'title' => __('Admin Email', 'fraktjakt-woocommerce-shipping'),
				'type' => 'text',
				'description' => __('Error Message from Module', 'fraktjakt-woocommerce-shipping')
		    )
			
			 
		);
	}
	
	/**
	 * Validate the consignor id and key
	 * @see validate_settings_fields()
	 */
	public function validate_consignor_id_field($key){
		$testmode = wp_kses_post( trim( stripslashes( $_POST[ $this->plugin_id . $this->id . '_' . 'test_mode' ] ) ) );
		$uri=($testmode==1)?'http://api2.fraktjakt.se/':'http://api1.fraktjakt.se/';
		$consignor_id = wp_kses_post( trim( stripslashes( $_POST[ $this->plugin_id . $this->id . '_' . $key ] ) ) );
		$consignor_key = wp_kses_post( trim( stripslashes( $_POST[ $this->plugin_id . $this->id . '_' . 'consignor_key' ] ) ) );
		if (($errmsg = test_connection($consignor_id, $consignor_key, $uri)) != "") {
			array_push($this->errors, $errmsg);
			return $consignor_id;
		}
		else {
			return $consignor_id;
		}
		
		
	}
	
	/**
	 * Display errors by overriding the display_errors() method
	 * @see display_errors()
	 */
	public function display_errors( ) {
	
		// loop through each error and display it
		foreach ( $this->errors as $key => $errmsg ) {
			//echo"<div class=\"error\"><p>Fraktjakt Warning:</p> <p>$errmsg</p></div>";
			?>
			<div class="error">
				<p>Fraktjakt Warning:</p>
				<p><?php _e( $errmsg, 'fraktjakt-woocommerce-shipping' ); ?></p>
			</div>
			<?php
		}
		
	}

				


				/**
				 * calculate_shipping function.
				 *
				 * @access public
				 * @param mixed $package
				 * @return void
				 */
				public function calculate_shipping( $package ) {
					global $woocommerce;
					
					    $cart_items = $woocommerce->cart->get_cart();
						$cart_amount = floatval( preg_replace( '#[^\d.]#', '', $woocommerce->cart->get_cart_total() ) );
						
						
						
						$xml ='<?xml version="1.0" encoding="UTF-8"?>'."\r\n";
						$xml.='<shipment>'."\r\n";
						$xml.=  '<value>'.$cart_amount.'</value>'."\r\n";
						$xml.=  '<consignor>'."\r\n";
						$xml.=	'<id>'.$this->consignor_id.'</id>'."\r\n";
						$xml.=	'<key>'.$this->consignor_key.'</key>'."\r\n";
						$xml.=	' <currency>SEK</currency>'."\r\n";
						$xml.=   ' <language>sv</language>'."\r\n";
						$xml.=   ' <encoding>UTF-8</encoding>'."\r\n";
						$xml  .= '   <system_name>WooCommerce</system_name>'."\r\n";
						$xml  .= '   <module_version>1.1.0</module_version>'."\r\n";
						$xml  .= '   <api_version>2.91</api_version>'."\r\n";
						$xml.= '</consignor>'."\r\n";
						$xml.= ' <parcels>'."\r\n";
						foreach ($cart_items as $id => $cart_item) {
						  $_product = $cart_item['data'];
						  $quantity= $cart_item['quantity'];
         				  $weight = $_product->weight;
						  $length = $_product->length;
						  $width = $_product->width;
						  $height = $_product->height;
						 for($i=1;$i<=$quantity;$i++)
						 { 
							  if($weight!='')
							  {
								$xml.='  <parcel>'."\r\n";
								$xml.='  <weight>'.$weight.'</weight>'."\r\n";
								$xml.='  <length>'.$length.'</length>'."\r\n";
								$xml.='  <width>'.$width.'</width>'."\r\n";
								$xml.=' <height>'.$height.'</height>'."\r\n";
								$xml.='</parcel>'."\r\n";
							  }
						 }
						
					}
					$xml.='</parcels>'."\r\n";
					$xml.=' <address_to>'."\r\n";
					
					$package['destination']['address']=($package['destination']['address']=='')?'Test street':$package['destination']['address'];
					$xml.=' <street_address_1>'.$package['destination']['address'].'</street_address_1>'."\r\n";
					
					$xml.= ' <street_address_2>'.$package['destination']['address_2'].'</street_address_2>'."\r\n";
					$xml.= ' <postal_code>'.$package['destination']['postcode'].'</postal_code>'."\r\n";
					$xml.= '<city_name>'.$package['destination']['city'].'</city_name>'."\r\n";
					$xml.=' <residential>1</residential>'."\r\n";
					$xml.= ' <country_code>'.$package['destination']['country'].'</country_code>'."\r\n";
					$xml.=  '</address_to>'."\r\n";
					$xml.='</shipment>'. "\r\n";
					$hash = md5($xml);
					$array=$hash; 
					
					if(true)
					{
					
							if($this->consignor_id!='' && $this->consignor_key!='' && $package['destination']['postcode']!='' && $package['destination']['country']!='')
							{	
								 $httpHeaders = array(
								  "Expect: ",
								  "Accept-Charset: UTF-8",
								  "Content-type: application/x-www-form-urlencoded"
								);
								$httpPostParams = array(
								  'md5_checksum' => md5($xml),
								  'xml' => utf8_encode($xml)
								);
								 if (is_array($httpPostParams)) {
								  foreach ($httpPostParams as $key => $value) {
									$postfields[$key] = $key .'='. urlencode($value);
								  }
								  $postfields = implode('&', $postfields);
								}
								
								$ch = curl_init($this->uri_query."fraktjakt/query_xml");
								curl_setopt($ch, CURLOPT_FAILONERROR, false); // fail on errors
								curl_setopt($ch, CURLOPT_FRESH_CONNECT, true); // forces a non-cached connection
								if ($httpHeaders) curl_setopt($ch, CURLOPT_HTTPHEADER, $httpHeaders); // set http headers
								curl_setopt($ch, CURLOPT_POST, true); // initialize post method
								curl_setopt($ch, CURLOPT_POSTFIELDS, $postfields); // variables to post
								curl_setopt($ch, CURLOPT_RETURNTRANSFER, true); // return into a variable
								curl_setopt($ch, CURLOPT_TIMEOUT, 30); // timeout after 30s
								$response = curl_exec($ch);
								curl_close($ch);
								$xml_data = simplexml_load_string( '<root>'.preg_replace( '/<\?xml.*\?>/', '', $response ).'</root>' );
								$array = json_decode(json_encode($xml_data), true);	
								//set_transient($hash, $array, 60 * 60 * 24 );
								if(is_array($array['shipment']))
								{
									
									$shipment_id=$array['shipment']['id'];
									foreach($array['shipment']['shipping_products']['shipping_product']	as $key=>$value)
									{
										$price=$total_price=$value['price'];
										$tax_class=$value['tax_class'];
										if($tax_class!='')
										{
											$total_price=$price+(($price/100)*$tax_class);
										}
										$description=$value['description'];
										$label="";
										
										
										$description_data=explode("-",$description);
										
										if($this->shipping_company_info=='yes')
										{
											$label.=$description_data[0];
										}
										if($this->shipping_product_info=='yes')
										{
											unset($description_data[0]);
											if($label!='')
											{
												$label.=", ";		
											}
											$label.=implode(" - ",$description_data);
										}
										
		
										if($this->distance_closest_delivery_info=='yes')
										{
											$label.='<br />';
											if((!is_array($value['agent_link']) || !is_array($value['agent_info'])))
											{
												$label.='<strong>'.__( 'Agent Name','fraktjakt-woocommerce-shipping' ).'</strong>';
												$label.=':&nbsp;';
												if(!is_array($value['agent_link']) && !is_array($value['agent_info']))
												{
													$label.='<a href="'. $value['agent_link'] .'" target="_blank" style="color: #666666;">';
												}
												if(!is_array($value['agent_info']))
												{
													$label.=$value['agent_info'];
												}
												if(!is_array($value['agent_link']) && !is_array($value['agent_info']))
												{
													$label.='</a>';
												}
											}
											else
											{
													$label.="<strong>".$this->dropoff_title."</strong>";
											}
											
										}
										if(!is_array($value['arrival_time']) && $this->estimated_delivery_info=='yes')
										{
												$label.='<br />';
												$label.='<strong>'.__( 'Arrival Time','fraktjakt-woocommerce-shipping' ).'</strong>';
												$label.=':&nbsp;';
												$label.=$value['arrival_time'];
											
										}
										$label.='<br><strong>'.__( 'Price','fraktjakt-woocommerce-shipping' ).'</strong>';
										
											$rate = array(
												'id' =>$this->id."_".$shipment_id."_".$value['id'],
												'label' => $label,
												'cost' => $total_price,
												'tax_class'=>$tax_class
											);
											
											$this->add_rate( $rate );
									}
								}
								else
								{
									if($this->fraktjakt_admin_email!='')
									{
										$message="";
										$message.="Code :".$array['shipment']['code']."<br>";
										$message.="Warning Code :".$array['shipment']['warning_message']."<br>";
										$message.="Error Message :".$array['shipment']['error_message']."<br>";
										$headers = array('Content-Type: text/html; charset=UTF-8');
										wp_mail($this->fraktjakt_admin_email, 'Error Message from Module', $message,$headers);
									}
									$rate = array(
										'id' =>$this->id,
										'label' =>$this->fallback_service_name,
										'cost' => $this->fallback_service_price,
										'tax_class'=>0
									);
									$this->add_rate($rate);
								}
										
							}
							
					}
					else
					{
								if(is_array($array['shipment']))
								{
									
									$shipment_id=$array['shipment']['id'];
									foreach($array['shipment']['shipping_products']['shipping_product']	as $key=>$value)
									{
										$price=$total_price=$value['price'];
										$tax_class=$value['tax_class'];
										if($tax_class!='')
										{
											$total_price=$price+(($price/100)*$tax_class);
										}
										$description=$value['description'];
										$label="";
										
										
										$description_data=explode("-",$description);
										
										if($this->shipping_company_info=='yes')
										{
											$label.=$description_data[0];
										}
										if($this->shipping_product_info=='yes')
										{
											unset($description_data[0]);
											if($label!='')
											{
												$label.=", ";		
											}
											$label.=implode(" - ",$description_data);
										}
										
		
										if($this->distance_closest_delivery_info=='yes')
										{
											$label.='<br />';
											if((!is_array($value['agent_link']) || !is_array($value['agent_info'])))
											{
												$label.='<strong>'.__( 'Agent Name','fraktjakt-woocommerce-shipping' ).'</strong>';
												$label.=':&nbsp;';
												if(!is_array($value['agent_link']) && !is_array($value['agent_info']))
												{
													$label.='<a href="'. $value['agent_link'] .'" target="_blank" style="color: #666666;">';
												}
												if(!is_array($value['agent_info']))
												{
													$label.=$value['agent_info'];
												}
												if(!is_array($value['agent_link']) && !is_array($value['agent_info']))
												{
													$label.='</a>';
												}
											}
											else
											{
													$label.="<strong>".$this->dropoff_title."</strong>";
											}
											
										}
										if(!is_array($value['arrival_time']) && $this->estimated_delivery_info=='yes')
										{
												$label.='<br />';
												$label.='<strong>'.__( 'Arrival Time','fraktjakt-woocommerce-shipping' ).'</strong>';
												$label.=':&nbsp;';
												$label.=$value['arrival_time'];
											
										}
										$label.='<br><strong>'.__( 'Price','fraktjakt-woocommerce-shipping' ).'</strong>';
										
											$rate = array(
												'id' =>$this->id."_".$shipment_id."_".$value['id'],
												'label' => $label,
												'cost' => $total_price,
												'tax_class'=>$tax_class
											);
											
											$this->add_rate( $rate );
									}
								}
								else
								{
									$rate = array(
										'id' =>$this->id,
										'label' =>$this->fallback_service_name,
										'cost' => $this->fallback_service_price,
										'tax_class'=>0
									);
									$this->add_rate($rate);
								}
					}
					
				}
			}
		}
	}



add_action( 'woocommerce_shipping_init', 'fraktjakt_shipping_method_init' );

function add_fraktjakt_shipping_method( $methods ) {
	$methods[] = 'WC_Fraktjakt_Shipping_Method';
	return $methods;
}
add_filter( 'woocommerce_shipping_methods', 'add_fraktjakt_shipping_method' );

function consignor_admin_error_notice() {
	$class = "error";
	$message = "Cosignor id OR Cosignor key missing";
        echo"<div class=\"$class\"> <p>$message</p></div>"; 
}

function test_connection($consignor_id, $consignor_key, $server) {
	$xml ='<?xml version="1.0" encoding="UTF-8"?>'."\r\n";
	$xml.='<shipment>'."\r\n";
	$xml.=  '<value>199.50</value>'."\r\n";
	$xml.= '<shipper_info>1</shipper_info>'."\r\n";
	$xml.=  '<consignor>'."\r\n";
	$xml.=	'<id>'.$consignor_id.'</id>'."\r\n";
	$xml.=	'<key>'.$consignor_key.'</key>'."\r\n";
	$xml.=	' <currency>SEK</currency>'."\r\n";
	$xml.=   ' <language>sv</language>'."\r\n";
	$xml.=   ' <encoding>UTF-8</encoding>'."\r\n";
	$xml  .= '   <system_name>WooCommerce</system_name>'."\r\n";
	$xml  .= '   <module_version>1.1.0</module_version>'."\r\n";
	$xml  .= '   <api_version>2.91</api_version>'."\r\n";
	$xml.= '</consignor>'."\r\n";
	$xml.= ' <parcels>'."\r\n";
	$xml.= '<parcel>'."\r\n";
    $xml.= '<weight>2.8</weight>'."\r\n";
    $xml.= '<length>30</length>'."\r\n";
    $xml.= '<width>20</width>'."\r\n";
    $xml.= '<height>10</height>'."\r\n";
   	$xml.= '</parcel>'."\r\n";
	$xml.='</parcels>'."\r\n";
	$xml.=' <address_to>'."\r\n";
	$xml.=' <street_address_1>>Hedenstorp 10</street_address_1>'."\r\n";
	$xml.= ' <street_address_2></street_address_2>'."\r\n";
	$xml.= ' <postal_code>33292</postal_code>'."\r\n";
	$xml.= '<city_name>Gislaved</city_name>'."\r\n";
	$xml.=' <residential>1</residential>'."\r\n";
	$xml.= ' <country_code>SE</country_code>'."\r\n";
	$xml.=  '</address_to>'."\r\n";
	$xml.='</shipment>'. "\r\n";
	
	$httpHeaders = array(
	  "Expect: ",
	  "Accept-Charset: UTF-8",
	  "Content-type: application/x-www-form-urlencoded"
	);
	$httpPostParams = array(
	  'md5_checksum' => md5($xml),
	  'xml' => utf8_encode($xml)
	);
	 if (is_array($httpPostParams)) {
	  foreach ($httpPostParams as $key => $value) {
		$postfields[$key] = $key .'='. urlencode($value);
	  }
	  $postfields = implode('&', $postfields);
	}
	
	$ch = curl_init($server."fraktjakt/query_xml");
	curl_setopt($ch, CURLOPT_FAILONERROR, false); // fail on errors
	curl_setopt($ch, CURLOPT_FRESH_CONNECT, true); // forces a non-cached connection
	if ($httpHeaders) curl_setopt($ch, CURLOPT_HTTPHEADER, $httpHeaders); // set http headers
	curl_setopt($ch, CURLOPT_POST, true); // initialize post method
	curl_setopt($ch, CURLOPT_POSTFIELDS, $postfields); // variables to post
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, true); // return into a variable
	curl_setopt($ch, CURLOPT_TIMEOUT, 30); // timeout after 30s
	$response = curl_exec($ch);
	curl_close($ch);
	$xml_data = simplexml_load_string( '<root>'.preg_replace( '/<\?xml.*\?>/', '', $response ).'</root>' );
	$array = json_decode(json_encode($xml_data), true);
	
	$message="";
	if(is_array($array['shipment'])) {
		if ($array['shipment']['code'] != 0) {
			$message.="Code :".$array['shipment']['code']."<br>";
			$message.="Warning Code :".$array['shipment']['warning_message']."<br>";
			$message.="Error Message :".$array['shipment']['error_message']."<br>";
		}
	}
	else {
		$message = "Unable to reach $server";
	}
	return $message;
}

function fraktjakt_shipping_complete($order_id){
	$order = new WC_Order( $order_id );
	$billing_email = get_post_meta( $order->id, '_billing_email',true );
	$billing_phone = get_post_meta( $order->id, '_billing_phone',true );
	$billing_first_name = get_post_meta( $order->id, '_billing_first_name',true );
	$billing_last_name = get_post_meta( $order->id, '_billing_last_name',true );
	
	
	$items = $order->get_items();
	$items_shipping = $order->get_items('shipping');
	foreach($items_shipping as $key=>$value)
	{
		$method=explode("_",$value['method_id']);
		$shipping_product_id=$method[count($method)-1];
		$shipment_id=$method[count($method)-2];
	}
		
	$fraktjakt_shipping_method_settings = get_option( 'woocommerce_fraktjakt_shipping_method_settings' );
	
	$uri_query=($fraktjakt_shipping_method_settings['test_mode']=='yes')?'http://api2.fraktjakt.se/':'http://api1.fraktjakt.se/';
	
		
		$xml =   '<?xml version="1.0" encoding="UTF-8"?>' . "\r\n";
		$xml.= '<OrderSpecification>' . "\r\n";
		$xml.= '  <consignor>' . "\r\n";
		$xml.= '    <id>'.$fraktjakt_shipping_method_settings['consignor_id'].'</id>' . "\r\n";
		$xml.= '    <key>'.$fraktjakt_shipping_method_settings['consignor_key'].'</key>' . "\r\n";
		$xml.= '    <currency>SEK</currency>' . "\r\n";
		$xml.= '    <language>sv</language>' . "\r\n";
		$xml  .= '   <system_name>WooCommerce</system_name>'."\r\n";
		$xml  .= '   <module_version>1.1.0</module_version>'."\r\n";
		$xml  .= '   <api_version>2.91</api_version>'."\r\n";
		$xml.= '  </consignor>' . "\r\n";
		$xml.= '  <shipment_id>'. $shipment_id .'</shipment_id>' . "\r\n";
		$xml.= '  <shipping_product_id>'. $shipping_product_id .'</shipping_product_id>' . "\r\n";
		$xml.= '  <reference>Woocommerce order #'. $order->id .'</reference>' . "\r\n";
		$xml.= '  <commodities>' . "\r\n";
		
		
     foreach ($items as $product) {

		$product_description = get_post($product['product_id'])->post_content;
		$description = ($product_description == '') ? $product['name'] : $product_description;

		$product_data = new WC_Product( $product['product_id'] );
		$xml .=  '    <commodity>' . "\r\n";
		$xml .= '      <name>'. $product['name'] .'</name>' . "\r\n";
		$xml .= '      <quantity>'. $product['qty'] .'</quantity>' . "\r\n";
		$xml .= '      <taric></taric>' . "\r\n";
		$xml .= '      <quantity_units>EA</quantity_units>' . "\r\n";
		$xml .= '      <description>'. $description .'</description>' . "\r\n";
		$xml .= '      <weight>'.$product_data->get_weight() .'</weight>' . "\r\n";
		$xml .= '      <unit_price>'. round($product['line_subtotal'], 2) .'</unit_price>' . "\r\n";
		$xml .= '    </commodity>' . "\r\n";
			
      }
	  $xml .=  '  </commodities>' . "\r\n";
	 
	  
		$xml .=  '  <recipient>' . "\r\n";
		$xml .=  '    <name_to>'.$billing_first_name.' '.$billing_last_name.'</name_to>' . "\r\n";
		$xml .=  '    <telephone_to>'.$billing_phone.'</telephone_to>' . "\r\n";
		$xml .=  '    <email_to>'.$billing_email.'</email_to>' . "\r\n";
		$xml .=  '  </recipient>' . "\r\n";
		
        $xml .=  ' </OrderSpecification>' . "\r\n";
		
			$httpHeaders = array(
			  "Expect: ",
			  "Accept-Charset: UTF-8",
			  "Content-type: application/x-www-form-urlencoded"
			);
			$httpPostParams = array(
			  'md5_checksum' => md5($xml),
			  'xml' => utf8_encode($xml)
			);
			if (is_array($httpPostParams)) {
			  foreach ($httpPostParams as $key => $value) {
				$postfields[$key] = $key .'='. urlencode($value);
			  }
			  $postfields = implode('&', $postfields);
			}
			$ch = curl_init($uri_query."orders/order_xml");
			curl_setopt($ch, CURLOPT_FAILONERROR, false); // fail on errors
			curl_setopt($ch, CURLOPT_FRESH_CONNECT, true); // forces a non-cached connection
			if ($httpHeaders) curl_setopt($ch, CURLOPT_HTTPHEADER, $httpHeaders); // set http headers
			curl_setopt($ch, CURLOPT_POST, true); // initialize post method
			curl_setopt($ch, CURLOPT_POSTFIELDS, $postfields); // variables to post
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, true); // return into a variable
			curl_setopt($ch, CURLOPT_TIMEOUT, 30); // timeout after 30s
			$response = curl_exec($ch);
			curl_close($ch);

}
add_action( 'woocommerce_order_status_processing', 'fraktjakt_shipping_complete' );
	
	
	
load_plugin_textdomain('fraktjakt-woocommerce-shipping', false, 'fraktjakt-woocommerce-shipping/languages/');
	
	
}
?>